@@ -48,11 +48,7 @@ class ForgeHgApp(RepositoryApp):
 
     @property
     def default_branch_name(self):
-        default_branch_name = getattr(self.repo, 'default_branch_name', 'default')
-        if not default_branch_name:
-            default_branch_name = 'default'
-        return default_branch_name
-
+        return self.repo.get_default_branch('default')
 
     def admin_menu(self):
         links = []
