@@ -87,12 +87,11 @@ class HgImplementation(M.RepositoryImplementation):
             ui.ui(), self._repo.full_fs_path, create=True)
         self.__dict__['_hg'] = repo
         self._setup_special_files()
-        self._repo.status = 'ready'
+        self._repo.set_status('ready')
 
     def clone_from(self, source_url):
         '''Initialize a repo as a clone of another'''
-        self._repo.status = 'cloning'
-        session(self._repo).flush(self._repo)
+        self._repo.set_status('cloning')
         log.info('Initialize %r as a clone of %s',
                  self._repo, source_url)
         try:
@@ -108,8 +107,7 @@ class HgImplementation(M.RepositoryImplementation):
             self.__dict__['_hg'] = repo
             self._setup_special_files(source_url)
         except:
-            self._repo.status = 'ready'
-            session(self._repo).flush(self._repo)
+            self._repo.set_status('ready')
             raise
 
     def commit(self, rev):
